@@ -1143,6 +1143,27 @@ class Consul(object):
                 callback,
                 '/v1/health/state/%s' % name, params=params)
 
+        def node(self, node, index=None):
+            """
+            Returns a tuple of (*index*, *checks*)
+
+            *index* is the current Consul index, suitable for making subsequent
+            calls to wait for changes since this query was last run.
+
+            *nodes* are the nodes providing the given service.
+            """
+            params = {}
+            if index:
+                params['index'] = index
+
+            def callback(response):
+                data = json.loads(response.body)
+                return response.headers['X-Consul-Index'], data
+
+            return self.agent.http.get(
+                callback,
+                '/v1/health/node/%s' % node, params=params)
+
     class Session(object):
         def __init__(self, agent):
             self.agent = agent
